#!/bin/sh

. /usr/local/bin/sig_catcher

usage() {
    echo "Usage:  dynamic_threshold_change.sh"
    echo "  Dynamically updates thermal management threshold based on shelf type"
    echo "  Supported shelf types: DS212, DS224, and DS424"
    exit 1 
}

if [ $# -ne 0 ]; then
    usage
fi

thres_update_log() {
# $1 - threshold change error code

	if [ "$1" -ne 0 ] ; then 	
		/usr/bin/logger "$operation failed" 
		exit 1
	else
		/usr/bin/logger "$operation done" 
	fi
}


case `cat /var/run/platform` in
    Vespa)
 	if [ -f /var/run/DS224 ]; then

		# nothing to do as SP default threshold to 2U threshold settings
		/usr/bin/logger "Vespa 2U shelf detected - no need to update thermal thresholds" 
		exit 0

 	elif [ -f /var/run/DS424 ]; then

		/usr/bin/logger "Vespa 4U shelf detected - dynamic thermal threshold update" 

		### Sensor id '0' - "In_flow_Temp"
		### Threshold setting
		###   crit-hi : 55.0
		###   warn-hi : 49.0 <- difference against DS224
		###   warn-lo : 10.0
		###   crit-lo : 0.0

        ### This block forces the sensor thresholds to values different from
        ### development/oem/firmware/IPMI/oem/netapp/Porting/platform/Vespa/Vespa.sdr

		# Warning HI to 49 
		operation="sensor thresh In_Flow_Temp unc 49"
		/usr/local/bin/ipmitool -A none -H 127.0.0.1 $operation
		thres_update_log $? $operation

		### Sensor id '1' - "Out_flow_Temp"
		### Threshold setting
		###   crit-hi : 67.0 <- difference against DS224
		###   warn-hi : 62.0 <- difference against DS224
		###   warn-lo : 10.0
		###   crit-lo : 0.0

		# Critical HI to 67 
		operation="sensor thresh Out_Flow_Temp ucr 67"
		/usr/local/bin/ipmitool -A none -H 127.0.0.1 $operation
		thres_update_log $? $operation

		# Warning HI to 62 
		operation="sensor thresh Out_Flow_Temp unc 62"
		/usr/local/bin/ipmitool -A none -H 127.0.0.1 $operation
		thres_update_log $? $operation

	elif [ -f /var/run/DS212 ]; then

		# Ruckus 2U
		# nothing to do as SP default threshold to 2U threshold settings
		/usr/bin/logger "Ruckus 2U shelf detected - no need to update thermal thresholds" 
		exit 0

	else

		echo "$Shelf type not supported - no thermal threshold update done"
		usage
		exit 1

	fi
	;;
    Helix|Zuma)
 	if [ -f /var/run/DS224 ]; then

		# nothing to do as SP default threshold to 2U threshold settings
		/usr/bin/logger "Tenaya 2U shelf detected - no need to update thermal thresholds" 
		exit 0

 	elif [ -f /var/run/DS424 ]; then

		/usr/bin/logger "Alpine 4U shelf detected - no need to update thermal threshold"
        exit 0

	elif [ -f /var/run/DS212 ]; then

		# Tioga 2U
		# nothing to do as SP default threshold to 2U threshold settings
		/usr/bin/logger "Tioga 2U shelf detected - no need to update thermal thresholds" 
		exit 0

	else

		echo "$Shelf type not supported - no thermal threshold update done"
		usage
		exit 1

	fi
    ;;
    *)
    	echo "Command not supported on this platform"
	exit 1
	;;
esac
exit 0
