#!/bin/sh

# config file is a text representation of the binary values in the prom.
# 
# the last two rows are version information (null terminated strings)
#

. /usr/local/bin/sig_catcher


if [ $# -lt 1 ]; then
    echo "Usage: $0 <filename>"
    exit 1
fi

filename=$1

addr=0xa0
numrows=0
totrows="`wc -l $filename | awk '{print $1}'`"
verrow="`expr $totrows - 2`"
adjust=0

if [ -f /var/run/Carnegie ]; then
# program in config information at offset 0
while [ $numrows -lt $totrows ]; do
    	linenum="`expr $numrows + 1`"
	val="`head -n $linenum $filename | tail -n 1`"
	if [ $numrows -ge $verrow ]; then
	    # adjust offset for version area
	    linenum=65
	fi
    	if [ $linenum -gt 16 ]; then 
		addr=0xa2
		adjust=16
	fi
    	if [ $linenum -gt 32 ]; then 
		addr=0xa4
		adjust=32
	fi
    	if [ $linenum -gt 48 ]; then 
		addr=0xa6
		adjust=48
	fi
    	if [ $linenum -gt 64 ]; then 
		addr=0xa8
		adjust=64
	fi
    	if [ $linenum -gt 80 ]; then 
		addr=0xaa
		adjust=80
	fi
    	if [ $linenum -gt 96 ]; then 
		addr=0xac
		adjust=96
	fi
    	if [ $linenum -gt 112 ]; then 
		addr=0xae
		adjust=112
	fi
	adjrow="`expr $numrows - $adjust`"
	indrow="`expr $adjrow \* 16`"
	ind="`echo $indrow|awk '{printf "%x",$1}'`"
	/usr/local/bin/i2c-test -b 5 -s $addr -m 0 -w -d $ind $val > /dev/null
	numrows="`expr $numrows + 1`"
done

# program in version information at offset 1024 (0x400)

# calculate checksums and compare

# config part
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 256 -d 0|tail -18 |head -16 > /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa2 -m 0 -rc 256 -d 0|tail -18 |head -16 >> /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa4 -m 0 -rc 256 -d 0|tail -18 |head -16 >> /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa6 -m 0 -rc 256 -d 0|tail -18 |head -16 >> /tmp/ddr_i2c_dump

# version part
/usr/local/bin/i2c-test -b 5 -s 0xa8 -m 0 -rc 32 -d 0|tail -n 4 |head -n 2 >> /tmp/ddr_i2c_dump
fi

if [ -f /var/run/Absolut ]; then
# program in config information at offset 0
while [ $numrows -lt $totrows ]; do
    	linenum="`expr $numrows + 1`"
	val="`head -n $linenum $filename | tail -n 1`"
	if [ $numrows -ge $verrow ]; then
	    # adjust offset for version area
	    linenum=65
	fi	
	indrow="`expr $numrows \* 16`"
#	ind="`echo $indrow|awk '{printf "%x",$1}'`"
	ind1=0
	ind2="`expr $indrow - 0`"
	ind2="`printf 0x%x $ind2`"
	if [ $indrow -ge 256 ]; then
		ind1=0x01
		ind2="`expr $indrow - 256`"
		ind2="`printf 0x%x $ind2`"
	fi
	if [ $indrow -ge 512 ]; then
		ind1=0x02
		ind2="`expr $indrow - 512`"
		ind2="`printf 0x%x $ind2`"
	fi
	if [ $indrow -ge 768 ]; then
		ind1=0x03
		ind2="`expr $indrow - 768`"
		ind2="`printf 0x%x $ind2`"
	fi
	if [ $indrow -ge 1024 ]; then
		ind1=0x04
		ind2="`expr $indrow - 1024`"
		ind2="`printf 0x%x $ind2`"
	fi
	/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -w -d $ind1 $ind2 $val > /dev/null
	numrows="`expr $numrows + 1`"
done

# program in version information at offset 1024 (0x400)

# calculate checksums and compare

# config part
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 256 -d 0x00 0x00|tail -18 |head -16 > /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 256 -d 0x01 0x00|tail -18 |head -16 >> /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 256 -d 0x02 0x00|tail -18 |head -16 >> /tmp/ddr_i2c_dump
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 256 -d 0x03 0x00|tail -18 |head -16 >> /tmp/ddr_i2c_dump

# version part
/usr/local/bin/i2c-test -b 5 -s 0xa0 -m 0 -rc 32 -d 0x04 0x00|tail -n 4 |head -n 2 >> /tmp/ddr_i2c_dump

fi

diff -bB /tmp/ddr_i2c_dump $filename 
if [ $? -eq 0 ]; then
    echo "Programmed successfully"
else
    echo "Did NOT program correctly! "
fi

rm /tmp/ddr_i2c_dump 
