#!/bin/sh

. /usr/local/bin/sig_catcher


WGET="/usr/bin/wget -q"
UNCOMPRESS="tar -zxf"
RM="rm -rf"
UMOUNT=/bin/umount
MOUNT=/bin/mount
TMPDIR=/tmp/FW
TMPFILE=image.tar.gz
NAND_ERASE=/usr/bin/flash_eraseall
NAND_WRITE="/usr/bin/nandwrite -p"
SPI_ERASE="/usr/bin/flash_erase"
SPI_WRITE="/usr/bin/flashcp"
UPDATE_PRIMARY=0
UPDATE_SECONDARY=0
UPDATE_CONFIG=0
UPDATE_TINY=0

LOG="/dev/null"

check_error() {
	if [ $? -gt 0 ]
	then
		echo "$0 make stopped due to error"
		exit 1
	fi
}

get_firmware_image() {
	mkdir -p $TMPDIR
	echo "[Getting Image]"
#	$WGET $1 -O $TMPDIR/$TMPFILE > $LOG 2> $LOG
	$WGET $1 -O $TMPDIR/$TMPFILE 
	check_error
	echo "-- Received $1 OK"
}

uncompress_firmware() {
	echo "[Uncompressing Image]"
	$UNCOMPRESS $TMPDIR/$TMPFILE -C $TMPDIR > $LOG 2> $LOG
	echo "-- OK"
}

program_nand_partition() {
#	$1: Partition Name
#	$2: MTD Device 
#	$3: File to be programmed
#	$4:	Mount point

	echo "[Updating $1 Partition]"

	if [ "$4" != "" ]
	then
		echo "--Unmounting $4"
		$UMOUNT $4	
		check_error
	fi
	echo "--Erasing $2"
	$NAND_ERASE $2 > $LOG 2>$LOG
	check_error

	echo "--Writing $3 to $2"
	$NAND_WRITE $2 $3 > $LOG 2>$LOG
	check_error

	if [ "$4" != "" ]
	then
		echo "--Mounting $4"
		$MOUNT $4	
		check_error
	fi
}

program_spi_partition() {
#	$1: Partition Name
#	$2: MTD Device 
#	$3: File to be programmed
	echo "[Updating $1 Partition]"

	echo "--Erasing $2"
	$SPI_ERASE $2 > $LOG 2>$LOG
	check_error

	echo "--Writing $3 to $2"
	$SPI_WRITE $3 $2 > $LOG 2>$LOG
	check_error
}

clean_up() {
	sync
	$RM $TMPDIR	
	echo "DONE"
}


usage() {
	echo "Usage: $0 [option] http://server/path/image.tar.gz"
	echo "Options:"
	echo "	-a: All partitions (equivalent to -p -s -c)"
	echo "	-p: Primary image only (u-boot, kernel, rootfs)"
	echo "	-s: Secondary image only (u-boot, kernel, rootfs)"
	echo "	-c: Configuration partition only"
	echo "	-r: Root FS partitions only"
	exit 2
}

# Here is the main program
if [ $# -le 0 ]; then
	usage
else
	while getopts apscrb c 
	do
		case $c in
			a)
				UPDATE_PRIMARY=1
				UPDATE_CONFIG=1
				UPDATE_SECONDARY=1
				;;
			p)
				UPDATE_PRIMARY=1
				;;
			s)
				UPDATE_SECONDARY=1
				;;
			c)
				UPDATE_CONFIG=1
				;;
			r)
				UPDATE_PRIMARY=1
				UPDATE_SECONDARY=1
				;;
			b)
				UPDATE_TINY=1
				;;
			*)
				usage
				;;	
		esac
		shift
	done
fi




get_firmware_image $1

uncompress_firmware 

if [ $UPDATE_PRIMARY == 1 ]
then
	program_spi_partition "Primary u-boot" /dev/mtd1 "$TMPDIR/u-boot.bin"
	program_nand_partition "Primary Kernel" /dev/mtd6 "$TMPDIR/uImage" 
	program_nand_partition "Primary RootFS" /dev/mtd7 "$TMPDIR/Root.bin" "/mnt/jffs2_rootfs_primary"
fi


if [ $UPDATE_SECONDARY == 1 ]
then
	program_spi_partition "Backup u-boot" /dev/mtd4 "$TMPDIR/secondary-u-boot.bin"
	program_nand_partition "Backup Kernel"  /dev/mtd8 "$TMPDIR/uImage"
	program_nand_partition "Backup RootFS"  /dev/mtd9 "$TMPDIR/Root.bin" "/mnt/jffs2_rootfs_backup"
fi

if [ $UPDATE_CONFIG == 1 ]
then
	killall eventd
	program_nand_partition "Config" /dev/mtd10 "$TMPDIR/Config.bin" "/mnt/logs" 
	/usr/local/bin/eventd
fi

if [ $UPDATE_TINY == 1 ]
then
	program_spi_partition "Primary Tiny-ROM" /dev/mtd0 "$TMPDIR/tiny-rom.bin"
	program_spi_partition "Secondary Tiny-ROM" /dev/mtd3 "$TMPDIR/tiny-rom.bin"
fi

clean_up
