#!/bin/sh

. /usr/local/bin/sig_catcher

status=0
primary=0
backup=0
executing=0
raw=0

#
# sp and acp print out similar data, so put this into a routine to 
#  reduce duplicated code
#
# $1: the descriptive text
# $2: the version number
#
# depends on $raw and $booted primary being set before calling
#
printvers() {

    if [ $raw -eq 0 ]
	then
		echo -n "Booted "
	fi
	if [ $booted_primary -gt 0 ]
	then
		if [ -e /var/run/netboot_fw ]
		then
			echo -n network
		else
			echo -n primary
		fi
	else
		echo -n backup
	fi
	if [ $raw -eq 0 ]
	then
		echo -n " $1"
	fi
	echo " $2"

}

#
# print out the versin information
#
# $1: descriptive text
# $2: sp version
# $3: acp version
#
printversrunning() {

	if [ $raw -eq 0 ]
	then
		echo -n "$1 firmware version "
	fi
	echo $2
	if [ $raw -eq 0 ] ; then
		echo "$1 ACP version $3"
	fi

}

while [ $# -gt 0 ]
do
	case "$1" in
		-a)
			status=1
			primary=1
			backup=1;;
		-s)
			status=1;;
		-e)
			executing=1;;
		-p)
			primary=1;;
		-b)
			backup=1;;
		-r)
			raw=1;;
		-*)
			echo  usage: $0 [-a] [-e] [-p] [-b] [-s] [-r]
			echo
			echo 	-a	print all info
			echo	-e	print executing firmware version
			echo 	-p	print primary firmware version
			echo 	-b	print backup firmware version
			echo 	-s	print executing firmware version status
			echo 	-r	print raw information
			exit 0
	esac
	shift
done

primary_version=`grep RLM_package_version /etc/rlm_install/primary/Metadata | cut -d= -f2 | cut -d" " -f1`
backup_version=`grep RLM_package_version /etc/rlm_install/backup/Metadata | cut -d= -f2 | cut -d" " -f1`
cur_version=`grep RLM_package_version /install/Metadata | cut -d= -f2 | cut -d" " -f1`

ACP_VERSION_FILE="/usr/local/acp/vespa_acp_version.txt"
acp_primary_version=$(cat /mnt/jffs2_rootfs_primary/${ACP_VERSION_FILE} 2> /dev/null)
acp_backup_version=$(cat /mnt/jffs2_rootfs_backup/${ACP_VERSION_FILE} 2> /dev/null)
acp_current_version=$(cat ${ACP_VERSION_FILE} 2> /dev/null)

[ -z "$acp_primary_version" ] && acp_primary_version='not present'
[ -z "$acp_backup_version" ] && acp_backup_version='not present'
[ -z "$acp_current_version" ] && acp_current_version='not present'



if [ -e /var/run/backup_fw ]
then
	booted_primary=0
else
	booted_primary=1
fi


if [ $status -gt 0 ] ; then
    printvers "firmware version" "$cur_version"
    printvers "ACP version" "$acp_current_version"
fi

[ $executing -gt 0 ] && printversrunning "Booted" "$cur_version" "$acp_current_version"

[ $primary -gt 0 ] && printversrunning "Primary" "$primary_version" "$acp_primary_version"

[ $backup -gt 0 ] && printversrunning "Backup" "$backup_version" "$acp_backup_version"

