#!/bin/sh
#
# Display ACP (eth0.16) interface status for system acp show command
# Script applies to Vespa platform only
#

. /usr/local/bin/sig_catcher

usage() {
    echo "Usage:  vespa_acp_inf_status.sh"
    exit 1 
}

config=/tmp/acp_eth0_16


#
# Check for Vespa platform type
#

if [ -f "/var/run/Vespa" ] || [ -f "/var/run/Helix" ] || [ -f "/var/run/Zuma" ] ; then
	#
	# Obtain eth0.16 of the ACP interface info
	#
	if ifconfig eth0.16 | grep -q UP ; then
		ifconfig eth0.16 > $config
	else
		# if eth0 has been downed, the address is still present in ifconfig
		# so filter it out now
		ifconfig eth0.16 | grep -v "inet addr" > $config
	fi
else
	echo "Unsupported on this platform"
	exit 1
fi

#
# Obtain IP address and netmask
#
IP=`awk '/inet addr/ {split($2, a, ":"); print a[2]}' $config`
MASK=`awk '/Mask/ {split($4, a, ":"); print a[2]}' $config`

#
# print out '-' if not ip address is not avaialable
#
if [ -z $IP ] ; then
	IP="-"
fi

#
# print out '-' if netmask is not avaialable
#
if [ -z $MASK ] ; then
	MASK="-"
fi

#
# get link status
#
UP_CHK=$(cat /sys/kernel/switch/ports/1/linkstatus)
if [ $UP_CHK == "up" ] || [ $UP_CHK == "Up" ] ; then
	LINK="up"
else
	LINK="down"
fi

#
# Output the result
#
echo "ACP Details"
echo "acpp ip address                : $IP"
echo "acpp netmask                   : $MASK"
echo "locked-wrench port link status : $LINK" 
echo

rm -f $config

exit 0
