#!/bin/sh

. /usr/local/bin/sig_catcher

# this is the value we're returning to the user
# to indicate if the operation worked based on what the programming tool returns
return_code=0

usage() {
    echo "Usage:  vespa_cpld_program <nvmem, acp, ebod, seq> <jamfile>"
    exit 1 
}

if [ $# -lt 2 ]; then
    usage
fi

target=$1

jamfile=$2

disable_all() {
	/usr/local/bin/gpiotool 2 2 --set-data-high
	/usr/local/bin/gpiotool 2 3 --set-data-high
	/usr/local/bin/gpiotool 2 4 --set-data-high
	/usr/local/bin/gpiotool 2 5 --set-data-high
}

case `cat /var/run/platform` in
    Vespa)
		# disable all cpld paths
		disable_all
    	case $target in
			nvmem)
				# enable nvmem cpld path
				/usr/local/bin/gpiotool 2 2 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			acp)
				# enable acp cpld path
				/usr/local/bin/gpiotool 2 3 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			ebod)
				# enable ebod cpld path
				/usr/local/bin/gpiotool 2 4 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			seq)
				# enable seq cpld path
				/usr/local/bin/gpiotool 2 5 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
    		*)
				echo "$target not supported."
				usage
			;;
		esac
		disable_all
	;;
     Helix|Zuma)
		# disable all cpld paths
		disable_all
    	case $target in
			nvmem)
				# enable nvmem cpld path
				/usr/local/bin/gpiotool 2 2 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			acp)
				# enable acp cpld path
				/usr/local/bin/gpiotool 2 3 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			ebod)
				# enable ebod cpld path
				/usr/local/bin/gpiotool 2 4 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
			seq)
				# enable seq cpld path
				/usr/local/bin/gpiotool 2 5 --set-data-low
				/usr/local/bin/cpldprog_altera -APROGRAM -ddo_real_time_isp=1 $jamfile
				return_code=$?
			;;
    		*)
				echo "$target not supported."
				usage
			;;
		esac
		disable_all
	;;
   *)
    	echo "Command not supported on this platform"
		return_code=1
    ;;
esac

exit $return_code
