#!/bin/sh

. /usr/local/bin/sig_catcher

i2ctest="/usr/local/bin/i2c-test"

usage() {
	echo "Usage: Does not accept any arguments"
    exit 1 
}

chip_name="Unknown"

# only allow -t as input parameter 
# for generating output in tuple format
# anything other input should print out usage help
if [ $# -gt 1 ] ; then
	usage
	exit 1
elif [ $# = 1 ] && [ $1 != -t ] ; then
	usage
	exit 1
fi

for channel in `echo 1 2 4 8`; do
	# setup channel of mux
	$i2ctest -b 2 -s 0xee -w -d $channel > /dev/null 2>&1

	# read type and revision from cpld

	case $channel in
		1)
			addr=0xb6
			chip_name="sequencer"
		;;
		2)
			addr=0xb0
			chip_name="ebod     "
		;;
		4)
			addr=0xb2
			chip_name="acp      "
		;;
		8)
			addr=0xb4
			chip_name="nvmem    "
		;;
	esac

	$i2ctest -b 2 -s $addr -rc 1 -d 0 > /dev/null 2>&1
	design_id=`$i2ctest -b 2 -s $addr -rc 1 -d 0 | head -2 |tail -1`
	chip_num=`$i2ctest -b 2 -s $addr -rc 1 -d 1 | head -2 |tail -1`
	rev_maj=`$i2ctest -b 2 -s $addr -rc 1 -d 2 | head -2 |tail -1|cut -c1-2`
	rev_maj=`printf "%d" 0x$rev_maj`
	rev_min=`$i2ctest -b 2 -s $addr -rc 1 -d 3 | head -2 |tail -1|cut -c1-2`
	rev_min=`printf "%d" 0x$rev_min`
	
	plat_type="Unknown"

	if [ $design_id -eq 1 ]; then
		plat_type="Vespa"
	fi


	if [ $# = 1 ] && [ $1 = -t ] ; then
		# tuple format used by collect_fw_vers.sh
		echo "fw_rev_$chip_name $rev_maj.$rev_min"
	else
		echo "$chip_name : rev $rev_maj.$rev_min"
	fi
done
